@@ -1,4 +1,4 @@
-/* $Id: display_plugin.c,v 1.8 2004/09/18 20:50:57 jasper Exp $ */
+/* $Id: display_plugin.c,v 1.9 2004/10/24 15:33:09 benny Exp $ */
 /*-
  * Copyright (c) 2003-2004 Benedikt Meurer <benny@xfce.org>
  *
@@ -49,7 +49,7 @@
 #define GAMMA_MAX	10.0
 
 /* */
-#define	RCDIR		"mcs_settings"
+#define	RCDIR		  "mcs_settings"
 #define	OLDRCDIR	"settings"
 #define	CHANNEL		"display"
 #define	RCFILE		"display.xml"
@@ -94,17 +94,34 @@ change_size_and_rate (XRRScreenConfiguration * sc, int size, int rate)
     int current_rate;
     int current_size;
 
+    gdk_error_trap_push ();
+
     current_rate = XRRConfigCurrentRate (sc);
     current_size = XRRConfigCurrentConfiguration (sc, &current_rotation);
 
+    if (gdk_error_trap_pop ())
+      {
+        g_warning ("display_plugin: Unable to query current display resolution");
+        return;
+      }
+
     if (size == current_size && rate == current_rate)
     {
         /* nothing to do here */
         return;
     }
 
-    XRRSetScreenConfigAndRate (GDK_DISPLAY (), sc, GDK_ROOT_WINDOW (), (SizeID) size, current_rotation, rate, CurrentTime);
+    gdk_error_trap_push ();
+
+    XRRSetScreenConfigAndRate (GDK_DISPLAY (), sc, GDK_ROOT_WINDOW (), (SizeID) size,
+                               current_rotation, rate, CurrentTime);
     XSync (GDK_DISPLAY (), False);
+
+    if (gdk_error_trap_pop ())
+      {
+        g_warning ("display_plugin: Unable to configure display resolution");
+        return;
+      }
 }
 #endif
 
@@ -120,7 +137,15 @@ change_gamma (double red, double green, double blue)
     gamma.green = green / 100.0;
     gamma.blue = blue / 100.0;
 
-    (void) XF86VidModeSetGamma (GDK_DISPLAY (), DefaultScreen (GDK_DISPLAY ()), &gamma);
+    gdk_error_trap_push ();
+
+    XF86VidModeSetGamma (GDK_DISPLAY (), DefaultScreen (GDK_DISPLAY ()), &gamma);
+
+    if (gdk_error_trap_pop ())
+      {
+        g_warning ("display_plugin: Unable to configure display gamma correction");
+        return;
+      }
 }
 #endif
 
